searchNodes=[{"doc":"A module to describe Internet domain names, together with some useful functions (testing if a domain is a subdomain of another, etc). This module does not implement the DNS protocol, it its only for domain names, independently of how they are used. You may use packages such as dns if you want DNS abilities. Examples iex&gt; d = DomainName . new! ( &quot;something.example.&quot; ) iex&gt; d2 = DomainName . new! ( &quot;EXAMPLE&quot; ) iex &gt; d3 = DomainName . new! ( &quot;fr&quot; ) iex &gt; DomainName . ends_with? ( d , d2 ) true iex&gt; DomainName . ends_with? ( d , d3 ) false","ref":"DomainName.html","title":"DomainName","type":"module"},{"doc":"Returns true if the domain name can be a host name (stricter syntax, see RFC 1123, section 2.1) Examples iex&gt; d = DomainName . new! ( &quot;example.com&quot; ) iex&gt; DomainName . can_be_hostname? ( d ) true iex&gt; d = DomainName . new! ( &quot;example$.com&quot; ) iex&gt; DomainName . can_be_hostname? ( d ) false","ref":"DomainName.html#can_be_hostname?/1","title":"DomainName.can_be_hostname?/1","type":"function"},{"doc":"Decode a domain name from the list of bytes in its wire representation.","ref":"DomainName.html#decode/1","title":"DomainName.decode/1","type":"function"},{"doc":"Decode a domain name from the list of bytes in its wire representation, and raises an exception if it is not a proper encoding.","ref":"DomainName.html#decode!/1","title":"DomainName.decode!/1","type":"function"},{"doc":"Encode a domain name in DNS wire format.","ref":"DomainName.html#encode/2","title":"DomainName.encode/2","type":"function"},{"doc":"Checks if a domain is a subdomain of one of the domains in the second parameter (and, if true, returns that parent domain). Examples iex&gt; d = DomainName . new! ( &quot;truc.machin.chose&quot; ) iex &gt; l = [ DomainName . new! ( &quot;example.com&quot; ) , DomainName . new! ( &quot;machin.chose&quot; ) , DomainName . new! ( &quot;fr&quot; ) ] iex&gt; DomainName . ends_with ( d , l ) { true , % DomainName { labels : [ &quot;machin&quot; , &quot;chose&quot; ] , name : &quot;machin.chose&quot; , original : &quot;machin.chose&quot; , original_labels : [ &quot;machin&quot; , &quot;chose&quot; ] } } iex&gt; l2 = [ DomainName . new! ( &quot;example.com&quot; ) , DomainName . new! ( &quot;fr&quot; ) ] iex &gt; DomainName . ends_with ( d , l2 ) false","ref":"DomainName.html#ends_with/2","title":"DomainName.ends_with/2","type":"function"},{"doc":"Checks if a domain is a subdomain of the other one. Examples iex&gt; d1 = DomainName . new! ( &quot;foobar.example.net&quot; ) iex &gt; d2 = DomainName . new! ( &quot;example.net&quot; ) iex &gt; DomainName . ends_with? ( d1 , d2 ) true iex&gt; d3 = DomainName . new! ( &quot;org&quot; ) iex &gt; DomainName . ends_with? ( d1 , d3 ) false","ref":"DomainName.html#ends_with?/2","title":"DomainName.ends_with?/2","type":"function"},{"doc":"Checks if two domain names are identical (in a case-insensitive way). Examples iex&gt; d1 = DomainName . new! ( &quot;example.com&quot; ) iex&gt; d2 = DomainName . new! ( &quot;example.COM&quot; ) iex&gt; DomainName . equal? ( d1 , d2 ) true iex&gt; d3 = DomainName . new! ( &quot;example.org&quot; ) iex&gt; DomainName . equal? ( d1 , d3 ) false","ref":"DomainName.html#equal?/2","title":"DomainName.equal?/2","type":"function"},{"doc":"Returns the domain name from the list of labels l . Examples iex&gt; { :ok , r } = DomainName . join ( [ &quot;some&quot; , &quot;thing&quot; , &quot;example&quot; ] ) iex&gt; DomainName . name ( r ) &quot;some.thing.example&quot;","ref":"DomainName.html#join/1","title":"DomainName.join/1","type":"function"},{"doc":"Returns the domain name from the subdomain s of the domain d . Examples iex&gt; d = DomainName . new! ( &quot;thing.example&quot; ) iex&gt; { :ok , r } = DomainName . join ( &quot;some&quot; , d ) iex&gt; DomainName . name ( r ) &quot;some.thing.example&quot;","ref":"DomainName.html#join/2","title":"DomainName.join/2","type":"function"},{"doc":"Returns the domain name from the list of labels l , and raises an exception if there is a problem. Examples iex&gt; r = DomainName . join! ( [ &quot;some&quot; , &quot;thing&quot; , &quot;example&quot; ] ) iex&gt; DomainName . name ( r ) &quot;some.thing.example&quot;","ref":"DomainName.html#join!/1","title":"DomainName.join!/1","type":"function"},{"doc":"Returns the domain name from the subdomain s of the domain d , and raises an exception if there is a problem. Examples iex&gt; d = DomainName . new! ( &quot;thing.example&quot; ) iex&gt; r = DomainName . join! ( &quot;some&quot; , d ) iex&gt; DomainName . name ( r ) &quot;some.thing.example&quot;","ref":"DomainName.html#join!/2","title":"DomainName.join!/2","type":"function"},{"doc":"Returns the list of labels in the domain name. Examples iex&gt; { :ok , d } = DomainName . new ( &quot;foo.bar.example.&quot; ) iex&gt; DomainName . labels ( d ) [ &quot;foo&quot; , &quot;bar&quot; , &quot;example&quot; ]","ref":"DomainName.html#labels/1","title":"DomainName.labels/1","type":"function"},{"doc":"Returns the domain name as a string. Examples iex&gt; d = DomainName . new! ( &quot;toto.fr&quot; ) iex &gt; DomainName . name ( d ) &quot;toto.fr&quot;","ref":"DomainName.html#name/1","title":"DomainName.name/1","type":"function"},{"doc":"Creates a DomainName from a string in dot-separated notation. s is the string, must_be_hostname indicates if the name must follow the stricter &quot;host syntax&quot;. Currently, the string must be in pure ASCII (no IDN). Examples iex&gt; { :ok , _d } = DomainName . new ( &quot;toto.fr&quot; ) iex&gt; DomainName . new ( &quot;toto fr&quot; , true ) { :error , &quot;Not a hostname (they are restricted to LDH)&quot; }","ref":"DomainName.html#new/2","title":"DomainName.new/2","type":"function"},{"doc":"Creates a DomainName from a string in dot-separated notation and raises the exception DomainName.Invalid if must_be_hostname is true and the name does not have the proper syntax. Apart from that, see the documentation for new/2 . Examples iex&gt; _d = DomainName . new! ( &quot;toto.fr&quot; ) iex &gt; _d = DomainName . new! ( &quot;toto. fr&quot; , true ) ** (DomainName.Invalid) Not a hostname (they are restricted to LDH)","ref":"DomainName.html#new!/2","title":"DomainName.new!/2","type":"function"},{"doc":"Returns the domain name as a string, in the original case (can be useful for things like case-randomization by resolvers). Examples iex&gt; d = DomainName . new! ( &quot;toTO.Fr&quot; ) iex &gt; DomainName . name ( d ) &quot;toto.fr&quot; iex&gt; DomainName . original ( d ) &quot;toTO.Fr&quot;","ref":"DomainName.html#original/1","title":"DomainName.original/1","type":"function"},{"doc":"Returns the TLD (Top-Level domain) of the domain name. Examples iex&gt; { :ok , d } = DomainName . new ( &quot;foo.bar.example.&quot; ) iex&gt; DomainName . tld ( d ) &quot;example&quot;","ref":"DomainName.html#tld/1","title":"DomainName.tld/1","type":"function"},{"doc":"DomainName is is a domain name. It is an opaque type and you should not access its fields, much less modify them.","ref":"DomainName.html#t:t/0","title":"DomainName.t/0","type":"opaque"},{"doc":"","ref":"DomainName.Invalid.html","title":"DomainName.Invalid","type":"exception"}]